==> haskell-vector-instances-3.4-102-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-Kxyf0hXXtac6GqjVDrX9kl
key: vector-instances-3.4-Kxyf0hXXtac6GqjVDrX9kl
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: 06b89f2eaa57e7b69a8e48d3850da4b5
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.6.4/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-Kxyf0hXXtac6GqjVDrX9kl
depends:
    base-4.12.0.0 comonad-5.0.4-It8ddWRP4jRldNSP0vxVN
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    keys-3.12.1-8q5XpZsUDnMFJ7ac2L3NH1
    pointed-5.0.1-AsjC8ExFqAC7FG3rlFBVSR
    semigroupoids-5.3.2-4vMxTU7QUhTAhqMRKNGi6Q
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4-103-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-AwjMlF6pbcsDMJgpPxxOEw
key: vector-instances-3.4-AwjMlF6pbcsDMJgpPxxOEw
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: a6b80c0829e8f218d466758090e08b38
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.6.4/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-AwjMlF6pbcsDMJgpPxxOEw
depends:
    base-4.12.0.0 comonad-5.0.4-3U3AOBIOmSp8ZoIXbLLva1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    keys-3.12.1-7g9YidLZ49t4HVdBhaSB4t
    pointed-5.0.1-8GdWhdkNeme1BeQN0tnp7e
    semigroupoids-5.3.2-lJuIn7iVWXJJzZoPYyt6n
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
